@@ -120,22 +120,3 @@ class WordListGetterMixin:
 
     def __len__(self):
         return len(self.wordlist)
-
-
-class Cities(WordListGetterMixin):
-    def __init__(self,
-                 country: Optional[Union[str, List[str]]] = None,
-                 ascii_safe: bool = False):
-        import os
-        filename = 'lists/top_100_cities.csv'
-        filepath = os.path.join(os.path.dirname(__file__), filename)
-        if not os.path.exists(filepath):
-            raise FileNotFoundError('Run text_sensitivity/data/lists/regenerate.py to regenerate files.')
-        main_column = 'ascii_name' if ascii_safe else 'name'
-        self.wordlist = WordList.from_csv(filepath, main_column=main_column, sep=';')
-
-        if country is not None:
-            self.filter('country_code', country)
-
-    def random(self, n: int, seed: Optional[int] = None):
-        return self.wordlist.random(n, likelihood_column='population', seed=seed)
