@@ -1,4 +1,5 @@
-# perturbations/characters.py
+"""Create character-level perturbations (`text_sensitivity.perturbation.base.Perturbation`)."""
+
 
 import numpy as np
 from typing import Callable
@@ -11,16 +12,16 @@ from text_sensitivity.perturbation.base import Perturbation, OneToOnePerturbatio
 
 def __construct(cls_or_fn, constructor_one, constructor_many, **kwargs):
     """Generic constructor, returning `constructor_many` if n > 1 else `constructor_one`."""
+    n = 1
     label_from = kwargs.pop('label_from') if 'label_from' in kwargs else 'original'
     label_to = kwargs.pop('label_to') if 'label_to' in kwargs else 'perturbed'
 
-    if 'n' in kwargs and isinstance(kwargs['n'], int) and kwargs['n'] > 1:
+    if 'n' in kwargs and isinstance(kwargs['n'], int):
         n = kwargs.pop('n')
-        if not isinstance(cls_or_fn, (str, dict, Callable)) or isinstance(cls_or_fn, type):
-            cls_or_fn = cls_or_fn(**kwargs)
-        return constructor_many(cls_or_fn, n=n, label_from=label_from, label_to=label_to)
     if not isinstance(cls_or_fn, (str, dict, Callable)) or isinstance(cls_or_fn, type):
-        cls_or_fn = cls_or_fn(**kwargs)
+        cls_or_fn = cls_or_fn(**kwargs)        
+    if n > 1:
+        return constructor_many(cls_or_fn, n=n, label_from=label_from, label_to=label_to)
     return constructor_one(cls_or_fn, label_from=label_from, label_to=label_to)
 
 
